'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var _extends = _interopDefault(require('@babel/runtime/helpers/extends'));
var _defineProperty = _interopDefault(require('@babel/runtime/helpers/defineProperty'));
var _objectWithoutProperties = _interopDefault(require('@babel/runtime/helpers/objectWithoutProperties'));
var core = require('@westpac/core');
var react = require('react');
var PropTypes = _interopDefault(require('prop-types'));
var heading = require('@westpac/heading');
var body = require('@westpac/body');

var Panel = function Panel(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("div", rest);
};

var panelStyles = function panelStyles(_, _ref2) {
  var look = _ref2.look;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  var styleMap = {
    hero: {
      borderColor: COLORS.hero
    },
    faint: {
      borderColor: COLORS.border
    }
  };
  return {
    marginBottom: '1.3125rem',
    backgroundColor: '#fff',
    border: "1px solid ".concat(styleMap[look].borderColor),
    borderRadius: '0.1875rem',
    table: {
      overflow: 'hidden',
      //clip overflow for rounded corners
      marginBottom: 0,
      borderBottomRightRadius: "calc(0.1875rem - 1px)",
      borderBottomLeftRadius: "calc(0.1875rem - 1px)"
    },
    'table caption': {
      padding: ['0.75rem 0.75rem 0 0.75rem', null, '1.5rem 1.5rem 0 1.5rem']
    }
  };
};

var panelAttributes = function panelAttributes() {
  return null;
};

var defaultPanel = {
  component: Panel,
  styles: panelStyles,
  attributes: panelAttributes
};

var Header = function Header(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("div", rest);
};

var headerStyles = function headerStyles(_, _ref2) {
  var look = _ref2.look;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  var mq = core.useMediaQuery();
  var styleMap = {
    hero: {
      backgroundColor: COLORS.hero,
      borderColor: COLORS.hero
    },
    faint: {
      backgroundColor: COLORS.background,
      borderColor: COLORS.border
    }
  };
  return mq({
    padding: ['0.625rem 0.75rem', null, '0.625rem 1.5rem'],
    backgroundColor: styleMap[look].backgroundColor,
    borderBottom: "1px solid ".concat(styleMap[look].borderColor),
    borderTopRightRadius: "calc(0.1875rem - 1px)",
    borderTopLeftRadius: "calc(0.1875rem - 1px)",
    '@media print': {
      borderBottom: '1px solid #000'
    }
  })[0];
};

var headerAttributes = function headerAttributes() {
  return null;
};

var defaultHeader = {
  component: Header,
  styles: headerStyles,
  attributes: headerAttributes
};

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var PanelHeading = function PanelHeading(_ref) {
  var headingTag = _ref.state.headingTag,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx(heading.Heading, _extends({
    tag: headingTag,
    size: 9
  }, rest));
};

var headingStyles = function headingStyles(_, _ref2) {
  var look = _ref2.look;

  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS,
      TYPE = _useBrand.TYPE;

  var styleMap = {
    hero: {
      color: '#fff'
    },
    faint: {
      color: COLORS.text
    }
  };
  return _objectSpread({
    color: styleMap[look].color
  }, TYPE.bodyFont[400]);
};

var headingAttributes = function headingAttributes() {
  return null;
};

var defaultHeading = {
  component: PanelHeading,
  styles: headingStyles,
  attributes: headingAttributes
};

var pkg = {
	name: "@westpac/panel",
	version: "1.0.0-beta.3",
	description: "Panel component for the Westpac GEL",
	repository: "https://github.com/WestpacGEL/GEL/tree/master/components/panel",
	author: "Westpac GEL Team <gel@westpac.com.au>",
	contributors: [
		{
			name: "Dominik Wilkowski",
			email: "Hi@Dominik-Wilkowski.com",
			url: "https://dominik-wilkowski.com"
		},
		{
			name: "Jonathan Stening",
			email: "info@jonathanstening.com",
			url: "http://jonathanstening.com"
		},
		{
			name: "Jeremy Ortiz",
			email: "jeremy@jeremyortiz.io",
			url: "https://www.jeremyortiz.io/"
		},
		{
			name: "Flore Laforge",
			email: "florelaforge@gmail.com",
			url: "http://florelaforge.com/"
		}
	],
	license: "GPL-3.0+",
	scripts: {
		start: "PACKAGE_NAME=panel webpack-dev-server --config ../../helpers/example/start.webpack.config.js",
		test: "exit 0 # start-server-and-test start http://localhost:8080 test:all",
		"test:dev": "start-server-and-test start http://localhost:8080 test:test-dev",
		"test:all": "yarn test:integration",
		"test:integration": "cypress run",
		"test:test-dev": "cypress open"
	},
	main: "dist/panel.cjs.js",
	module: "dist/panel.esm.js",
	dependencies: {
		"@babel/runtime": "^7.9.6",
		"@westpac/body": "^1.1.0",
		"@westpac/core": "^1.0.1",
		"@westpac/heading": "^1.0.0-beta.2",
		"prop-types": "^15.7.2"
	},
	peerDependencies: {
		react: "^16.13.1"
	},
	devDependencies: {
		"@westpac/table": ">1.0.0-alpha",
		cypress: "^4.5.0",
		react: "^16.13.1",
		"start-server-and-test": "^1.11.0"
	}
};

function ownKeys$1(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$1(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$1(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$1(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Context and Consumer Hook
// ==============================

var PanelContext = react.createContext();
var usePanelContext = function usePanelContext() {
  var context = react.useContext(PanelContext);

  if (!context) {
    throw new Error('<Body/> and <Footer/> components should be wrapped in a <Panel>.');
  }

  return context;
}; // ==============================
// Component
// ==============================

var Panel$1 = function Panel(_ref) {
  var look = _ref.look,
      heading = _ref.heading,
      headingTag = _ref.headingTag,
      children = _ref.children,
      componentOverrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["look", "heading", "headingTag", "children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var defaultOverrides = {
    Panel: defaultPanel,
    Header: defaultHeader,
    Heading: defaultHeading
  };

  var state = _objectSpread$1({
    look: look,
    heading: heading,
    headingTag: headingTag,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$P = _overrideReconciler.Panel,
      Panel = _overrideReconciler$P.component,
      panelStyles = _overrideReconciler$P.styles,
      panelAttributes = _overrideReconciler$P.attributes,
      _overrideReconciler$H = _overrideReconciler.Header,
      Header = _overrideReconciler$H.component,
      headerStyles = _overrideReconciler$H.styles,
      headerAttributes = _overrideReconciler$H.attributes,
      _overrideReconciler$H2 = _overrideReconciler.Heading,
      Heading = _overrideReconciler$H2.component,
      headingStyles = _overrideReconciler$H2.styles,
      headingAttributes = _overrideReconciler$H2.attributes;

  return core.jsx(PanelContext.Provider, {
    value: {
      state: state
    }
  }, core.jsx(Panel, _extends({}, rest, {
    state: state
  }, panelAttributes(state), {
    css: panelStyles(state)
  }), core.jsx(Header, _extends({
    state: state
  }, headerAttributes(state), {
    css: headerStyles(state)
  }), core.jsx(Heading, _extends({
    state: state
  }, headingAttributes(state), {
    css: {
      '&&': headingStyles(state)
    }
  }), heading)), children));
}; // ==============================
// Types
// ==============================

Panel$1.propTypes = {
  /**
   * Panel look
   */
  look: PropTypes.oneOf(['hero', 'faint']).isRequired,

  /**
   * Panel heading text
   */
  heading: PropTypes.string.isRequired,

  /**
   * Panel heading tag
   */
  headingTag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]).isRequired,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Panel: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Header: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    }),
    Heading: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};
Panel$1.defaultProps = {
  look: 'hero',
  headingTag: 'h1'
};

var bodyStyles = function bodyStyles() {
  var _useBrand = core.useBrand(),
      SPACING = _useBrand.SPACING;

  var mq = core.useMediaQuery();
  return mq({
    padding: [SPACING(2), null, SPACING(4)]
  })[0];
};

var bodyAttributes = function bodyAttributes() {
  return null;
};

var defaultBody = {
  component: body.Body,
  styles: bodyStyles,
  attributes: bodyAttributes
};

function ownKeys$2(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$2(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$2(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$2(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var PanelBody = function PanelBody(_ref) {
  var children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = usePanelContext();
  var defaultOverrides = {
    Body: defaultBody
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$2({
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$B = _overrideReconciler.Body,
      Body = _overrideReconciler$B.component,
      bodyStyles = _overrideReconciler$B.styles,
      bodyAttributes = _overrideReconciler$B.attributes;

  return core.jsx(Body, _extends({}, rest, {
    state: state
  }, bodyAttributes(state), {
    css: bodyStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

PanelBody.propTypes = {
  /**
   * Panel body content
   */
  children: PropTypes.node,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Body: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

var Footer = function Footer(_ref) {
  var state = _ref.state,
      rest = _objectWithoutProperties(_ref, ["state"]);

  return core.jsx("div", rest);
};

var footerStyles = function footerStyles() {
  var _useBrand = core.useBrand(),
      COLORS = _useBrand.COLORS;

  var mq = core.useMediaQuery();
  return mq({
    padding: ['0.625rem 0.75rem', null, '0.625rem 1.5rem'],
    backgroundColor: COLORS.light,
    borderTop: "1px solid ".concat(COLORS.border),
    borderBottomRightRadius: "calc(0.1875rem - 1px)",
    borderBottomLeftRadius: "calc(0.1875rem - 1px)"
  })[0];
};

var footerAttributes = function footerAttributes() {
  return null;
};

var defaultFooter = {
  component: Footer,
  styles: footerStyles,
  attributes: footerAttributes
};

function ownKeys$3(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$3(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys$3(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys$3(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }
// Component
// ==============================

var PanelFooter = function PanelFooter(_ref) {
  var children = _ref.children,
      overrides = _ref.overrides,
      rest = _objectWithoutProperties(_ref, ["children", "overrides"]);

  var _useBrand = core.useBrand(),
      tokenOverrides = _useBrand.OVERRIDES[pkg.name],
      brandOverrides = _useBrand[pkg.name];

  var context = usePanelContext();
  var defaultOverrides = {
    Footer: defaultFooter
  };
  var componentOverrides = overrides || context.state.overrides;

  var state = _objectSpread$3({
    context: context.state,
    overrides: componentOverrides
  }, rest);

  var _overrideReconciler = core.overrideReconciler(defaultOverrides, tokenOverrides, brandOverrides, componentOverrides),
      _overrideReconciler$F = _overrideReconciler.Footer,
      Footer = _overrideReconciler$F.component,
      footerStyles = _overrideReconciler$F.styles,
      footerAttributes = _overrideReconciler$F.attributes;

  return core.jsx(Footer, _extends({}, rest, {
    state: state
  }, footerAttributes(state), {
    css: footerStyles(state)
  }), children);
}; // ==============================
// Types
// ==============================

PanelFooter.propTypes = {
  /**
   * Panel footer content
   */
  children: PropTypes.node,

  /**
   * The override API
   */
  overrides: PropTypes.shape({
    Footer: PropTypes.shape({
      styles: PropTypes.func,
      component: PropTypes.elementType,
      attributes: PropTypes.func
    })
  })
};

exports.Body = PanelBody;
exports.Footer = PanelFooter;
exports.Panel = Panel$1;
